@@ -23,6 +23,7 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
+#include <pulse/pulseaudio.h>
 
 #include <telepathy-glib/telepathy-glib.h>
 
@@ -30,6 +31,7 @@
 
 #include "empathy-call-utils.h"
 
+#include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-request-util.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
@@ -192,3 +194,32 @@ empathy_call_new_with_streams (const gchar *contact,
   g_hash_table_unref (streamed_media_request);
   g_object_unref (call_req);
 }
+
+void
+empathy_call_set_stream_properties (GstElement *element)
+{
+  GstStructure *props;
+  GSettings *gsettings_call;
+  gboolean echo_cancellation;
+
+  gsettings_call = g_settings_new (EMPATHY_PREFS_CALL_SCHEMA);
+
+  echo_cancellation = g_settings_get_boolean (gsettings_call,
+      EMPATHY_PREFS_CALL_ECHO_CANCELLATION);
+
+  props = gst_structure_new ("props",
+      PA_PROP_MEDIA_ROLE, G_TYPE_STRING, "phone",
+      NULL);
+
+  if (echo_cancellation)
+    {
+      gst_structure_set (props,
+          "filter.want", G_TYPE_STRING, "echo-cancel",
+          NULL);
+    }
+
+  g_object_set (element, "stream-properties", props, NULL);
+  gst_structure_free (props);
+
+  g_object_unref (gsettings_call);
+}
