@@ -71,7 +71,9 @@ GQuark empathy_tp_chat_get_feature_ready (void) G_GNUC_CONST;
 
 GType          empathy_tp_chat_get_type             (void) G_GNUC_CONST;
 
-EmpathyTpChat *empathy_tp_chat_new                  (TpAccount *account,
+EmpathyTpChat *empathy_tp_chat_new                  (
+						     TpSimpleClientFactory *factory,
+						     TpAccount *account,
 						     TpConnection *connection,
 						     const gchar *object_path,
 						     const GHashTable *immutable_properties);
@@ -93,9 +95,6 @@ GPtrArray *    empathy_tp_chat_get_properties       (EmpathyTpChat      *chat);
 const GList *  empathy_tp_chat_get_pending_messages (EmpathyTpChat *chat);
 void           empathy_tp_chat_acknowledge_message (EmpathyTpChat *chat,
 						     EmpathyMessage *message);
-void           empathy_tp_chat_acknowledge_messages (EmpathyTpChat *chat,
-						     const GSList *messages);
-void           empathy_tp_chat_acknowledge_all_messages (EmpathyTpChat *chat);
 
 gboolean       empathy_tp_chat_can_add_contact (EmpathyTpChat *self);
 
